@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2015 Synchrotron SOLEIL
+ * Copyright (C) 2003-2016 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -235,23 +235,21 @@ static HklParameterOperations hkl_parameter_operations_axis = {
 	.quaternion_get = hkl_axis_quaternion_get_real
 };
 
-HklParameter *hkl_parameter_new_axis(char const *name, HklVector const *axis_v)
+HklParameter *hkl_parameter_new_axis(const char *name, HklVector const *axis_v, const HklUnit *punit)
 {
-	HklAxis *self = NULL;
-	static HklAxis axis0 = {
-		.parameter = {
-			HKL_PARAMETER_DEFAULTS_ANGLE,
-			.ops = &hkl_parameter_operations_axis,
+	HklAxis axis0 = {
+		.parameter = { HKL_PARAMETER_DEFAULTS_ANGLE,
+			       .name = name,
+			       .punit = punit,
+			       .ops = &hkl_parameter_operations_axis,
 		},
-		.q = {{1, 0, 0, 0}},
+		.axis_v = *axis_v,
+		.q = {{1., 0., 0., 0.}},
 	};
 
-	self = HKL_MALLOC(HklAxis);
-
+	HklAxis *self =  HKL_MALLOC(HklAxis);
 
 	*self = axis0;
-	self->parameter.name = name;
-	self->axis_v = *axis_v;
 
 	return &self->parameter;
 }
