@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2015 Synchrotron SOLEIL
+ * Copyright (C) 2003-2016 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -93,6 +93,9 @@ struct _HklGeometryListItem
 extern HklParameter *hkl_holder_add_rotation_axis(HklHolder *self,
 						  char const *name, double x, double y, double z);
 
+extern HklParameter *hkl_holder_add_rotation_axis_with_punit(HklHolder *self,
+							     char const *name, double x, double y, double z,
+							     const HklUnit *punit);
 /***************/
 /* HklGeometry */
 /***************/
@@ -124,6 +127,8 @@ extern int hkl_geometry_closest_from_geometry_with_range(HklGeometry *self,
 
 extern int hkl_geometry_is_valid(const HklGeometry *self);
 
+extern int hkl_geometry_is_valid_range(const HklGeometry *self);
+
 /*******************/
 /* HklGeometryList */
 /*******************/
