@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2015 Synchrotron SOLEIL
+ * Copyright (C) 2003-2016 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -24,19 +24,14 @@
 #include <tap/float.h>
 #include <tap/hkl-tap.h>
 
-/* use these private methods */
-HklParameter *hkl_parameter_new_axis(const char *, const HklVector *axis_v);
-int hkl_parameter_is_valid(const HklParameter *parameter);
-void hkl_parameter_value_set_smallest_in_range(HklParameter *parameter);
-double hkl_parameter_value_get_closest(HklParameter *parameter, HklParameter *ref);
+#include <hkl-axis-private.h>
 
 static void new(void)
 {
 	HklParameter *axis;
 	static HklVector v = {{1, 0, 0}};
 	double min, max;
-
-	axis = hkl_parameter_new_axis("omega", &v);
+	axis = hkl_parameter_new_axis("omega", &v, &hkl_unit_angle_deg);
 
 	is_string("omega", hkl_parameter_name_get(axis), __func__);
 	hkl_parameter_min_max_get(axis, &min, &max, HKL_UNIT_DEFAULT);
@@ -55,7 +50,7 @@ static void get_quaternions(void)
 	static HklQuaternion q2_ref = {{M_SQRT1_2, -M_SQRT1_2, 0, 0}};
 	HklParameter *axis;
 
-	axis = hkl_parameter_new_axis("omega", &v_ref);
+	axis = hkl_parameter_new_axis("omega", &v_ref, &hkl_unit_angle_deg);
 
 	is_quaternion(&q1_ref, hkl_parameter_quaternion_get(axis), __func__);
 
@@ -74,7 +69,7 @@ static void copy(void)
 	double min, max;
 
 
-	axis = hkl_parameter_new_axis("omega", &v);
+	axis = hkl_parameter_new_axis("omega", &v, &hkl_unit_angle_deg);
 	ok(TRUE == hkl_parameter_value_set(axis, -M_PI_2, HKL_UNIT_DEFAULT, NULL), __func__);
 
 	copy = hkl_parameter_new_copy(axis);
@@ -97,7 +92,7 @@ static void is_valid(void)
 	static HklVector v = {{1, 0, 0}};
 	HklParameter *axis1;
 
-	axis1 = hkl_parameter_new_axis("omega", &v);
+	axis1 = hkl_parameter_new_axis("omega", &v, &hkl_unit_angle_deg);
 
 	ok(TRUE == hkl_parameter_value_set(axis1, 45, HKL_UNIT_USER, NULL), __func__);
 	ok(TRUE == hkl_parameter_is_valid(axis1), __func__);
@@ -129,7 +124,7 @@ static void set_value_smallest_in_range(void)
 	HklParameter *axis;
 	static HklVector v = {{1, 0, 0}};
 
-	axis = hkl_parameter_new_axis("omega", &v);
+	axis = hkl_parameter_new_axis("omega", &v, &hkl_unit_angle_deg);
 
 	ok(TRUE == hkl_parameter_min_max_set(axis, -190, 190, HKL_UNIT_USER, NULL), __func__);
 
@@ -165,8 +160,8 @@ static void get_value_closest(void)
 	HklParameter *axis1, *axis2;
 	static HklVector v = {{1, 0, 0}};
 
-	axis1 = hkl_parameter_new_axis("omega", &v);
-	axis2 = hkl_parameter_new_axis("omega", &v);
+	axis1 = hkl_parameter_new_axis("omega", &v, &hkl_unit_angle_deg);
+	axis2 = hkl_parameter_new_axis("omega", &v, &hkl_unit_angle_deg);
 
 	ok(TRUE == hkl_parameter_value_set(axis1, 0, HKL_UNIT_USER, NULL), __func__);
 	ok(TRUE == hkl_parameter_value_set(axis2, 0, HKL_UNIT_USER, NULL), __func__);
