@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2015 Synchrotron SOLEIL
+ * Copyright (C) 2003-2016 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -292,6 +292,36 @@ static void wavelength(void)
 	hkl_geometry_free(geom);
 }
 
+static void  xxx_rotation_get(void)
+{
+	int res = TRUE;
+	size_t i, n;
+	HklFactory **factories;
+	HklDetector *detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
+	HklSample *sample = hkl_sample_new("test");
+
+	factories = hkl_factory_get_all(&n);
+	for(i=0; i<n && TRUE == res; i++){
+		HklGeometry *geometry = NULL;
+		HklQuaternion q_ref = {{1, 0, 0, 0}};
+		HklQuaternion qs;
+		HklQuaternion qd;
+
+		geometry = hkl_factory_create_new_geometry(factories[i]);
+		qs = hkl_geometry_sample_rotation_get(geometry, sample);
+		qd = hkl_geometry_detector_rotation_get(geometry, detector);
+
+		res &= DIAG(TRUE == hkl_quaternion_cmp(&q_ref, &qs));
+		res &= DIAG(TRUE == hkl_quaternion_cmp(&q_ref, &qd));
+
+		hkl_geometry_free(geometry);
+	}
+	ok(res, __func__);
+
+	hkl_detector_free(detector);
+	hkl_sample_free(sample);
+}
+
 static void list(void)
 {
 	int i = 0;
@@ -401,25 +431,25 @@ static void  list_remove_invalid(void)
 
 	res &= DIAG(hkl_geometry_set_values_v(g, HKL_UNIT_DEFAULT, NULL,
 					      185. * HKL_DEGTORAD,
-					      -185.* HKL_DEGTORAD,
+					      -185. * HKL_DEGTORAD,
 					      185. * HKL_DEGTORAD));
 	hkl_geometry_list_add(list, g);
 
 	res &= DIAG(hkl_geometry_set_values_v(g, HKL_UNIT_DEFAULT, NULL,
 					      -190. * HKL_DEGTORAD,
-					      -190.* HKL_DEGTORAD,
-					      -190.* HKL_DEGTORAD));
+					      -190. * HKL_DEGTORAD,
+					      -190. * HKL_DEGTORAD));
 	hkl_geometry_list_add(list, g);
 
 	res &= DIAG(hkl_geometry_set_values_v(g, HKL_UNIT_DEFAULT, NULL,
 					      180. * HKL_DEGTORAD,
-					      180.* HKL_DEGTORAD,
-					      180.* HKL_DEGTORAD));
+					      180. * HKL_DEGTORAD,
+					      180. * HKL_DEGTORAD));
 	hkl_geometry_list_add(list, g);
 
 	is_int(3, hkl_geometry_list_n_items_get(list), __func__);
 	hkl_geometry_list_remove_invalid(list);
-	is_int(2, hkl_geometry_list_n_items_get(list), __func__);
+	is_int(1, hkl_geometry_list_n_items_get(list), __func__);
 
 	ok(res, __func__);
 
@@ -429,7 +459,7 @@ static void  list_remove_invalid(void)
 
 int main(void)
 {
-	plan(50);
+	plan(51);
 
 	add_holder();
 	get_axis();
@@ -439,6 +469,7 @@ int main(void)
 	distance();
 	is_valid();
 	wavelength();
+	xxx_rotation_get();
 
 	list();
 	list_multiply_from_range();
